Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1029)

Unified Diff: components/autofill/content/renderer/password_autofill_agent.h

Issue 2775963002: s/same_page/same_document for DidCommitProvisionalLoad method. (Closed)
Patch Set: Addressed review comment Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/renderer/password_autofill_agent.h
diff --git a/components/autofill/content/renderer/password_autofill_agent.h b/components/autofill/content/renderer/password_autofill_agent.h
index 20f9c6aad5668f48aefca4c2ac702d5bf45f2ea7..3594022cdc1be281aaa71d3e48d5683973d1696b 100644
--- a/components/autofill/content/renderer/password_autofill_agent.h
+++ b/components/autofill/content/renderer/password_autofill_agent.h
@@ -200,7 +200,7 @@ class PasswordAutofillAgent : public content::RenderFrameObserver,
void DidStartProvisionalLoad(blink::WebDataSource* data_source) override;
void WillCommitProvisionalLoad() override;
void DidCommitProvisionalLoad(bool is_new_navigation,
- bool is_same_page_navigation) override;
+ bool is_same_document_navigation) override;
void WillSendSubmitEvent(const blink::WebFormElement& form) override;
void WillSubmitForm(const blink::WebFormElement& form) override;
void OnDestruct() override;
@@ -251,8 +251,8 @@ class PasswordAutofillAgent : public content::RenderFrameObserver,
const blink::WebInputElement& input,
ProvisionallySaveRestriction restriction);
- // Helper function called when in-page navigation completed
- void OnSamePageNavigationCompleted();
+ // Helper function called when same-document navigation completed
+ void OnSameDocumentNavigationCompleted();
const mojom::AutofillDriverPtr& GetAutofillDriver();

Powered by Google App Engine
This is Rietveld 408576698